@@ -1,10 +1,11 @@
 //! MRT BGP4MP structs
 use std::net::IpAddr;
+use serde::Serialize;
 use crate::bgp::BgpMessage;
 use crate::network::{Afi, Asn};
 
 /// BGP states enum.
-#[derive(Debug, Primitive, Copy, Clone)]
+#[derive(Debug, Primitive, Copy, Clone, Serialize, PartialEq)]
 pub enum BgpState {
     Idle = 1,
     Connect = 2,
@@ -15,7 +16,7 @@ pub enum BgpState {
 }
 
 /// BGP4MP message types.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Serialize)]
 pub enum Bgp4Mp {
     Bgp4MpStateChange(Bgp4MpStateChange),
     Bgp4MpStateChangeAs4(Bgp4MpStateChange),
@@ -26,7 +27,7 @@ pub enum Bgp4Mp {
 }
 
 /// BGP4MP message subtypes.
-#[derive(Debug, Primitive, Copy, Clone)]
+#[derive(Debug, Primitive, Copy, Clone, Serialize, PartialEq)]
 pub enum Bgp4MpType {
     Bgp4MpStateChange = 0,
     Bgp4MpMessage = 1,
@@ -41,7 +42,7 @@ pub enum Bgp4MpType {
 }
 
 /// BGP4MP state change message.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Serialize)]
 pub struct Bgp4MpStateChange {
     pub peer_asn: Asn,
     pub local_asn: Asn,
@@ -54,7 +55,7 @@ pub struct Bgp4MpStateChange {
 }
 
 /// BGP4MP state change message with 4-byte ASN.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Serialize)]
 pub struct Bgp4MpStateChangeAs4 {
     pub peer_asn: Asn,
     pub local_asn: Asn,
@@ -67,7 +68,7 @@ pub struct Bgp4MpStateChangeAs4 {
 }
 
 /// BGP4MP message.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Serialize)]
 pub struct Bgp4MpMessage {
     pub peer_asn: Asn,
     pub local_asn: Asn,
